@@ -50,6 +50,7 @@ class BBOXPoint():
         return BBOXPoint(self.Y,self.X)   
     def __repr__(self):
         return "[{0},{1}]".format(str(self.X),str(self.Y))
+
     @classmethod
     def from_azure(cls, data):
         return cls(**data)
@@ -83,6 +84,10 @@ class BBOXPoint():
         points.append(BBOXPoint(x,y,ppi))
         return points
 
+    @classmethod
+    def from_aws(cls, data):
+        return cls(**data)
+
 class BBOXNormalizedLine():
     def __init__(self, Idx, BoundingBox: List[BBOXPoint], Text:str = None, merged:bool=False, avg_height=0.0, std_height=0.0, words_count=0):
         self.start_idx=Idx+1
@@ -201,18 +206,30 @@ class BBOXNormalizedLine():
         for bb in range(4):
             points.append(BBOXPoint(0,0))
         # 
-        points[0].X = line_boxes[0][0].x 
-        points[0].Y = line_boxes[0][0].y 
-        points[3].X = line_boxes[0][3].x 
-        points[3].Y = line_boxes[0][3].y
+        points[0].X = line_boxes[0][0]["x"] 
+        points[0].Y = line_boxes[0][0]["y"] 
+        points[3].X = line_boxes[0][3]["x"] 
+        points[3].Y = line_boxes[0][3]["y"]
 
-        points[1].X = line_boxes[-1][1].x 
-        points[1].Y = line_boxes[-1][1].y 
-        points[2].X = line_boxes[-1][2].x 
-        points[2].Y = line_boxes[-1][2].y 
+        points[1].X = line_boxes[-1][1]["x"] 
+        points[1].Y = line_boxes[-1][1]["y"] 
+        points[2].X = line_boxes[-1][2]["x"] 
+        points[2].Y = line_boxes[-1][2]["y"] 
 
         return BBOXNormalizedLine(Idx=line_counter,BoundingBox=points,Text=line_text,words_count=words_count)
 
+    @classmethod
+    def from_aws(cls, index, data):
+        points = list()
+        line_text=''
+        array=data["Geometry"]["Polygon"]
+        points = list(map(BBOXPoint.from_aws, [x for x in array]))
+
+        if "Text" in data:
+            line_text=data["Text"]
+
+        return cls(Idx=index,BoundingBox=points,Text=line_text,std_height=0,avg_height=0,words_count=0)
+
 class BBOXPageLayout():
     def __init__(self, Id:int = 0,clockwiseorientation:float = 0.0,Width:float = 0.0,Height:float = 0.0,Unit:str = "pixel",Language:str="en",Text:str=None,Lines:List[BBOXNormalizedLine]=None,ppi=1):
         self.id=Id
@@ -224,6 +241,7 @@ class BBOXPageLayout():
         self.text=Text
         self.lines=Lines
         self.ppi=ppi
+
     @classmethod
     def from_azure(cls, page):
         lines=list()
@@ -296,20 +314,21 @@ class BBOXPageLayout():
         line_text =""
         line_boxes=[]
         line_words_count=0
-
-        bboxlogger.debug("Google|Page shape (Height,Width) ({0},{1})".format(page.height,page.width))
+        page_width=page["width"]
+        page_height=page["height"]
+        bboxlogger.debug("Google|Page shape (Height,Width) ({0},{1})".format(page_height,page_width))
         # Create the concept of lines for Google ocr response. 
-        for idb, block in enumerate(page.blocks):
-            for paragraph in block.paragraphs:
-                pagearray = np.zeros((page.height,page.width))
+        for idb, block in enumerate(page["blocks"]):
+            for paragraph in block["paragraphs"]:
+                pagearray = np.zeros((page_height,page_width))
                 # parray=page[paragraph.bounding_box.vertices[0].y:paragraph.bounding_box.vertices[2].y,paragraph.bounding_box.vertices[0].x:paragraph.bounding_box.vertices[2].x]
-                bboxlogger.debug("Google|Paragraph {0} of {1} words".format(str(idb),str(len(paragraph.words))))
-                for widx, word in enumerate(paragraph.words):
+                bboxlogger.debug("Google|Paragraph {0} of {1} words".format(str(idb),str(len(paragraph["words"]))))
+                for widx, word in enumerate(paragraph["words"]):
                     # Put the word presence in the paragraph matrix 
-                    low_y=word.bounding_box.vertices[0].y-1
-                    high_y=word.bounding_box.vertices[2].y
-                    low_x=word.bounding_box.vertices[0].x-1
-                    high_x=word.bounding_box.vertices[2].x
+                    low_y=word["boundingBox"]["vertices"][0]["y"]-1
+                    high_y=word["boundingBox"]["vertices"][2]["y"]
+                    low_x=word["boundingBox"]["vertices"][0]["x"]-1
+                    high_x=word["boundingBox"]["vertices"][2]["x"]
                     # the Min,Max allows us to handle vertical words. 
                     pagearray[min(low_y,high_y):max(low_y,high_y),min(low_x,high_x):max(low_x,high_x)]=widx+1
 
@@ -318,15 +337,15 @@ class BBOXPageLayout():
                 # Assign the first cluster as current
                 currentTextColumn = columns[0]
 
-                for widx, word in enumerate(paragraph.words):
+                for widx, word in enumerate(paragraph["words"]):
                     if len(columns)==1:
                         foundTextColumn = columns[0]
                     else:                       
                         # Find the word cluster
                         for cidx,column in enumerate(columns):
-                            if word.bounding_box.vertices[0].x >= column[0] and word.bounding_box.vertices[0].x <= column[1]:
+                            if word["boundingBox"]["vertices"][0]["x"] >= column[0] and word["boundingBox"]["vertices"][0]["x"] <= column[1]:
                                 foundTextColumn = column
-                                bboxlogger.debug("Google|Word Idx:{0} X:{1} in Cluster {2}".format(widx,word.bounding_box.vertices[0].x,column))
+                                bboxlogger.debug("Google|Word Idx:{0} X:{1} in Cluster {2}".format(widx,word["boundingBox"]["vertices"][0]["x"],column))
 
                     # Line break on text columns change.
                     if len(line_boxes)>0:
@@ -343,24 +362,77 @@ class BBOXPageLayout():
                                 line_words_count=0
 
                     currentTextColumn=foundTextColumn
-                    line_boxes.append(word.bounding_box.vertices)                   
+                    line_boxes.append(word["boundingBox"]["vertices"])                   
                     line_words_count+=1
-                    for symbol in word.symbols:
-                        line_text+=symbol.text
-                        if symbol.property.detected_break:
-                            if symbol.property.detected_break.type in [1,2]:
-                                line_text+=" "
-                            elif symbol.property.detected_break.type in [3,5]:
-                                bboxlogger.debug("Google|Detected Line Break {0}| {1} {2}".format(str(symbol.property.detected_break.type),str(line_counter),line_text))
-                                # Line Break
-                                line=BBOXNormalizedLine.from_google(line_counter,line_text,line_boxes,words_count=line_words_count)
-                                lines.append(line)
-                                line_text=""
-                                line_counter+=1
-                                line_boxes.clear()
-                                line_words_count=0                                
+                    for symbol in word["symbols"]:
+                        line_text+=symbol["text"]
+                        if "property" in symbol:
+                            if "detectedBreak" in symbol["property"]:
+                                bboxlogger.debug("Google|Detected Break {0}".format(str(symbol["property"]["detectedBreak"]["type"])))                            
+                                if symbol["property"]["detectedBreak"]["type"] in ['SPACE','SURE_SPACE',1,2]:
+                                    line_text+=" "
+                                elif symbol["property"]["detectedBreak"]["type"] in ['EOL_SURE_SPACE','LINE_BREAK',3,5]:
+                                    bboxlogger.debug("Google|Detected Line Break {0}| {1} {2}".format(str(symbol["property"]["detectedBreak"]["type"]),str(line_counter),line_text))
+                                    # Line Break
+                                    line=BBOXNormalizedLine.from_google(line_counter,line_text,line_boxes,words_count=line_words_count)
+                                    lines.append(line)
+                                    line_text=""
+                                    line_counter+=1
+                                    line_boxes.clear()
+                                    line_words_count=0                                
+
+        return cls(Id=1,Width=page_width,Height=page_height,Lines=lines)
+
+    @classmethod
+    def from_aws(cls, page, width, height):
+        lines=list()
+
+        # TODO #1
+        if "unit" in page:
+            page_unit=page["unit"]
+            if page_unit=="inch":
+                # Azure OCR response doesn't provide the ppi per page
+                # so we need to determine it for normalizing the processing of lines
+                # ppi=BBoxUtils.determine_ppi(data["width"],data["height"])
+                
+                # decimal precision on Azure is set to 4, so we can set a 10000 to normalize the box and 
+                # not convert to pixel
+                ppi=10000
+            else:
+                ppi=1
+        else:
+            page_unit="pixel"
+            ppi=1
+
+        # Page Width / Heigth
+        if "width" in page:
+            page_width=page["width"]
+            page_height=page["height"]
+        else:
+            page_width=width
+            page_height=height
+
+        # Denormalize the Geometry/Polygon
+        for block in page:
+            for coordinate in block["Geometry"]["Polygon"]:
+                coordinate["X"]=coordinate["X"]*width
+                coordinate["Y"]=coordinate["Y"]*height
+
+        lines=[BBOXNormalizedLine.from_aws(i,line) for i,line in enumerate(page) if (line["BlockType"] == "LINE")]
+
+        bboxlogger.debug("AWS|Page shape (Height,Width) ({0},{1})".format(page_width,page_height))
+
+        # AWS doesn't provide an angle or text orientation
+        angle=0.0
+
+        # Page Id
+        if "page" in page:
+            page_id=page["page"]
+        else:
+            page_id="1"
+
+        return cls(Id=page_id,clockwiseorientation=angle,Width=page_width,Height=page_height,Unit=page_unit,Lines=lines,ppi=ppi)
 
-        return cls(Id=1,Width=page.width,Height=page.height,Lines=lines)
 
 class BBOXOCRResponse():
     def __init__(self,status:str = None,Text:str=None,original_text:str=None,recognitionResults:List[BBOXPageLayout]=None):
@@ -394,10 +466,23 @@ class BBOXOCRResponse():
             status = "ocrsuccess"
 
         return cls(status=status,recognitionResults=pages)
+    
     @classmethod
-    def from_google(cls, document):
-        pages = list(map(BBOXPageLayout.from_google,document.pages))
-        return cls(status="success",original_text=document.text,recognitionResults=pages)
+    def from_google(cls, data):
+        if "fullTextAnnotation" in data:
+            pages = list(map(BBOXPageLayout.from_google,data["fullTextAnnotation"]["pages"]))
+            return cls(status="success",original_text=data["fullTextAnnotation"]["text"],recognitionResults=pages)
+
+    @classmethod
+    def from_aws_detect_document_text(cls, data, width, height):
+        pages=list()
+        pages.append(BBOXPageLayout.from_aws(data["Blocks"],width,height))
+        if "status" in data:
+            status = data["status"]
+        else:
+            status = "awssuccess"
+
+        return cls(status=status,recognitionResults=pages)
 
 class BBoxHelper():
 
@@ -432,7 +517,8 @@ class BBoxHelper():
         elif isinstance(input,BBOXOCRResponse):
             response=input
 
-        return self.__processOCRResponse(response,sortingAlgo,boxSeparator)
+        if response:
+            return self.__processOCRResponse(response,sortingAlgo,boxSeparator)
 
     def processGoogleOCRResponse(self,input,sortingAlgo=BBoxSort.contoursSort,boxSeparator:str = None,verbose=None):
         """ processGoogleOCRResponse method
@@ -441,10 +527,35 @@ class BBoxHelper():
         if verbose:
             bboxlogger.setLevel(logging.DEBUG)
             
-        #Create an BBOXOCRResponse object from Google input
-        response=BBOXOCRResponse.from_google(input)
+        #load the input json into a response object
+        if isinstance(input,str):
+            response=BBOXOCRResponse.from_google(json.loads(input))
+        if isinstance(input,dict):
+            response=BBOXOCRResponse.from_google(input)
+        elif isinstance(input,BBOXOCRResponse):
+            response=input
+
+        if response:
+            return self.__processOCRResponse(response,sortingAlgo,boxSeparator)
+
+    def processAWSOCRResponse(self,input,width,height,sortingAlgo=BBoxSort.contoursSort,boxSeparator:str = None,verbose=None):
+        """ processAWSOCRResponse method
+            Process an OCR Response input from AWS and returns a new BBox format OCR response.
+        """
+        if verbose:
+            bboxlogger.setLevel(logging.DEBUG)
+
+        #load the input json into a response object
+        if isinstance(input,str):
+            response=BBOXOCRResponse.from_aws_detect_document_text(json.loads(input),width,height)
+        if isinstance(input,dict):
+            response=BBOXOCRResponse.from_aws_detect_document_text(input,width,height)
+        elif isinstance(input,BBOXOCRResponse):
+            response=input
+
+        if response:
+            return self.__processOCRResponse(response,sortingAlgo,boxSeparator)
 
-        return self.__processOCRResponse(response,sortingAlgo,boxSeparator)
 
     def __processOCRResponse(self, response, sortingAlgo=BBoxSort.contoursSort, boxSeparator:str = None):
         """processOCRResponse method
